"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Commander = require("commander");
var cipher_1 = require("./cipher");
var datakey_1 = require("./datakey");
var fs = require("fs");
function kmsVault(argv, config) {
    Commander.version("0.1.0")
        .option("-r, --region <region>", "AWS_REGION(default is `us-east-1`)")
        .option("-k, --key <kmsKeyAlias>", "KMS CMK alias name")
        .option("-f, --infile <filepath>", "Input Filename(The file must be written in utf8 or ascii.)");
    Commander.command("decrypt")
        .description("encrypted base64 string to plain string use CMK.")
        .arguments("[encryptedBase64String]")
        .action(function (encryptedBase64String, options) {
        config = config || createConfigFromArgs(options);
        var cipher = new cipher_1.Cipher.Cipher(config);
        encryptedBase64String = encryptedBase64String || fs.readFileSync(options.parent.infile, { encoding: "utf8" });
        cipher.decrypt(encryptedBase64String)
            .then(function (plainStr) {
            console.log(plainStr);
            process.exit(0);
        })
            .catch(function (err) {
            console.error(err);
            process.exit(1);
        });
    });
    Commander.command("encrypt")
        .description("plain string to encrypted base64 use CMK")
        .arguments("[plainStr]")
        .action(function (plainStr, options) {
        config = config || createConfigFromArgs(options);
        var cipher = new cipher_1.Cipher.Cipher(config);
        plainStr = plainStr || fs.readFileSync(options.parent.infile, { encoding: "utf8" });
        cipher.encrypt(plainStr)
            .then(function (encrypted) {
            console.log(encrypted);
            process.exit(0);
        })
            .catch(function (err) {
            console.error(err);
            process.exit(1);
        });
    });
    Commander.command("datakey")
        .description("generate datakey use CMK")
        .action(function (options) {
        config = config || createConfigFromArgs(options);
        datakey_1.DataKey.generate(config.kmsKeyAlias, config.awsOpts)
            .then(function (blob) {
            console.log(blob.toString("base64"));
            process.exit(0);
        })
            .catch(function (err) {
            console.error(err);
            process.exit(1);
        });
    });
    //to display "help" when no args
    if (argv.length < 3)
        argv.push("--help");
    Commander.parse(argv);
}
exports.default = kmsVault;
function createConfigFromArgs(options) {
    return {
        kmsKeyAlias: options.parent.key,
        awsOpts: {
            region: options.parent.region || "us-east-1"
        }
    };
}
